//book.cpp.  Copyright (C) 2004 Dan Honeycutt.  You are free
//to use this software.  There is no warranty of any kind.

#include <time.h>
#include <stdlib.h>
//#include <iostream> // cout
#include "book.h"

//CBook seeds the random number generator.  Change the following
//to 0 (or call srand(1) after startup) if you want fixed random
//numbers for debugging etc.  Of course if you do this the moves
//selected from the book won't be random.
static const int seed_random_number_generator = 1;

//Move selection goes through the list of moves for a position 
//comparing move value with a random number.  A move with the
//maximum value is guaranteed to be played as soon as it is found.
//A move with value 0 is guaranteed not to be played.
static const int bk_max_value = 4;   //must be power of two

//default book - follows below.
extern CBookMov bk_default_book[];

//====================================================================
//GetBookMove() returns a book move for the current position.
//Calls SelectBookMove() which chooses the move.
//====================================================================
const char *CBook::GetBookMove(const CBookPos *cur_pos) {
  const char *promote = "  NBRQ";
  static char buffer[6];
  int i, move;
  char *pc = buffer;
  if (move = SelectBookMove(cur_pos)) {
    //book move available - format to ascii
    for (i = 0; i < 2; i++) {
      *pc++ = 'a' + (move & 7);
      *pc++ = '1' + ((move & 63) >> 3);
      move >>= 6;
    }
    i = move & 7;
    if ((i > 1) && (i < 6)) *pc++ = promote[i];
  }
  *pc = 0;
  //std::cout << "\n" << buffer << "\n";
  return buffer;
} //GetBookMove()

//====================================================================
//SelectBookMove() makes the random selection of a move according to
//move value.  There is some probability that no move will be 
//selected even if moves are avalable.
//Calls FindBookEntry() to get moves to select from.
//====================================================================
int CBook::SelectBookMove(const CBookPos *cur_pos) {
  const int mask = bk_max_value - 1;
  int i, k = 0;
  char c;
  //do a quick validity check and piece count
  for (i = 0; i < 64; i++) {  
    c = cur_pos->bk_board[i];
    if (c) {
      k++;
      if ((c < 0) || (c > 15)) return 0;
    }
  }
  if (k < bk_min_men) return 0;             //too few pieces
  if (!FindBookEntry(cur_pos)) return 0;    //position not found
  if (bk_num_moves == 0) return 0;          //position has no moves

  k = 0;
  while (1) {
    for (i = 0; i < bk_num_moves; i++) {
      if (bk_entry.bk_value[i] > (rand() & mask)) return (bk_entry.bk_moves[i]);
    }
    //went thru the list with no move selected
    //randomly (w/increasing chance) leave
    if (++k > (rand() & 3)) break;
  } //while
  return (0);
} //SelectBookMove()

//====================================================================
//FindBookEntry() looks for the current position in the book.  Returns 
//true if the position is found and member variable bk_entry will have 
//the moves.  Looks first for the current position and, if not found,
//looks again for the position with colors reversed.
//Calls BinSearch() to perform the actual search.
//====================================================================
int CBook::FindBookEntry(const CBookPos *cur_pos) {
  int i, move, b1, b2, pro;
  char c;
  CBookPos temp;

  if (i = BinSearch(GetHashKey(cur_pos))) {
    color_reverse_flag = 0;
    CopyBookEntry(i);
    return 1;
  }
  //failed to find position, reverse colors and try again
  for (i = 0; i < 64; i++) {
    c = cur_pos->bk_board[i];
    if (c) c ^= 8;                    //toggle piece color
    temp.bk_board[Flip(i)] = c;      //flip square
  }
  c = cur_pos->bk_ep_target;
  if ((c < 16) || (c > 47)) c = 0;
  if (c) c = Flip(c);
  temp.bk_ep_target = c;
  temp.bk_color = !cur_pos->bk_color;
  i = BinSearch(GetHashKey(&temp));
  if (!i) return 0;
  //found the color reverse position. moves have to be reversed
  color_reverse_flag = 1;
  CopyBookEntry(i);
  for (i = 0; i < bk_num_moves; i++) {
    move = bk_entry.bk_moves[i];
    b1 = Flip(move & 63);
    b2 = Flip((move >> 6) & 63);
    pro = (move >> 12) & 7;
    bk_entry.bk_moves[i] = b1 + (b2 << 6) + (pro << 12);
  }
  return 1;
} //FindBookEntry()

//====================================================================
//BinSearch() performs search for target position.  Since the keys 
//are random, the value of target tells approximately where it
//resides in the list.  BinSearch() finds a window around target then
//performs a binary search of the window.
//====================================================================
int CBook::BinSearch(bk_bbd target) {
  int lo, mid, hi;
  bk_bbd key;

  mid = (int) (target >> 33);   //whittle down to signed 4 byte size
  lo = hi = (int) (bk_num_pos * (((float)mid)/2147483647.0f));
  mid = 1 + (bk_num_pos >> 7);  //window ~ 1% of total positions
  //get a window around target
  while (BookEntryKey(lo) > target) {   //window too high
    hi = lo;          //move hi down to lo
    lo -= mid;        //move lo down by window size
    mid *= 2;         //expand window size
    if (lo < 1) {     //check limits
      lo = 1;
      break;
    }
  }
  while (BookEntryKey(hi) < target) {   //window too low
    lo = hi;
    hi += mid;
    mid *= 2;
    if (hi > bk_num_pos) {
      hi = bk_num_pos;
      break;
    }
  }
  //now do a binary search on the window
  while (lo <= hi) {
    mid = (lo + hi) / 2;
    key = BookEntryKey(mid);
    if (target < key) 
      hi = mid - 1;
    else if (target > key)
      lo = mid + 1;
    else
      return mid;       //found the position
  }
  return 0;             //search fails
} //BinSearch()

//====================================================================
//Utility Routines:
//Flip() color reverses a square
//GetHashKey() returns hash key for a CBookPos
//BookEntryKey() returns the key corresponding to index passed
//CopyBookEntry() copies entry to bk_entry and sets number of moves
//====================================================================
int CBook::Flip(int sq) {
  return 8*(7-(sq >> 3)) + (sq & 7);
} //Flip()

bk_bbd CBook::GetHashKey(const CBookPos *p1) {
  int i;
  char c;
  bk_bbd key = 0;
  for (i = 0; i < 64; i++) {
    if (c = p1->bk_board[i]) key ^= bk_rnd[c][i];
  }
  //bk_rnd[8][0] is black-to-move
  if (p1->bk_color) key ^= bk_rnd[8][0];
  //bk_rnd[0][sq] is en passant target
  c = p1->bk_ep_target;
  if ((c < 16) || (c > 47)) c = 0;
  if (c) key ^= bk_rnd[0][c];
  return key;
} //GetHashKey()

bk_bbd CBook::BookEntryKey(int ix) {
  if (bk_using_default) {
    return bk_default_book[ix].bk_key;
  }
  //future - file
  return 0;
} //BookEntryKey()

void CBook::CopyBookEntry(int ix) {
  if (bk_using_default) {
    bk_entry = bk_default_book[ix];
  } else {
    //future - file
    bk_entry.bk_moves[0] = 0;   //no moves
  }
  //set the number of moves
  for (ix = 0; ix < BK_MAX_MOVES; ix++) {
    if (!bk_entry.bk_moves[ix]) break;
  }
  bk_num_moves = ix;
} //CopyBookEntry()

//====================================================================
//InitBook() is called at startup by constructor.  All it does is set
//the default book.  Future plans are too look for a book on disk
//and set a file pointer to that if found.
//====================================================================
void CBook::InitBook() {
  extern bk_bbd random_numbers[];
  //cast random_numbers[1024] to bk_rnd[16][64]
  bk_rnd = (bk_bbd (*)[64]) random_numbers;
  //seed random numbers unless told not to
  if (seed_random_number_generator) {
    srand((unsigned)time(NULL));
  }
  //set default book
  bk_using_default = 1;
  //first record has number positions and minimum pieces
  bk_num_pos = (int) bk_default_book[0].bk_key;
  bk_min_men = bk_default_book[0].bk_moves[0];
  //future - file
} //InitBook()

//====================================================================
//the book
//====================================================================
CBookMov bk_default_book[924] = {
{923,{0},{0},{25}},
{0x00004cd1156e0a42,{0},{3,2},{2434,1292}},
{0x0012df17cf27ef9e,{0},{3},{64}},
{0x003af1ebb780bc67,{0},{4},{2284}},
{0x006b3a53773c00e6,{0},{3,3,2},{3194,2618,1661}},
{0x009789cbe7b14273,{0},{3,3,2,2},{2356,2942,2745,2226}},
{0x00c174c387640d0d,{0},{3,3},{3389,1699}},
{0x00e2602d2ad84abc,{0},{4},{1350}},
{0x01a97858cb4a23d6,{0},{3,2},{2291,2942}},
{0x021ad8b866a45bec,{0},{4},{2267}},
{0x0280570256b1f676,{0},{3},{1739}},
{0x029814ccb093d89a,{0},{3,2},{2426,1978}},
{0x02c4ddb841ac7596,{0},{3,1},{2745,2933}},
{0x02c6777874b0b731,{0},{4},{1827}},
{0x02e29ee4ab343dc9,{0},{4},{1112}},
{0x0329638b8895dfe2,{0},{3},{2942}},
{0x03309304b8ce33fc,{0},{3},{388}},
{0x0338b47e5f6c05a2,{0},{3,2},{1539,901}},
{0x033b3bfa5c1198c8,{0},{3,2},{2998,2942}},
{0x034077a56edea074,{0},{4},{2737}},
{0x037f21863ddf88eb,{0},{4},{2268}},
{0x038d1125fc5be54b,{0},{3},{1114}},
{0x03b16117856bb2bc,{0},{4},{1292}},
{0x03d28794a0b871bf,{0},{4},{2291}},
{0x03f71ce16ae7962e,{0},{4},{2331}},
{0x040050873d704eab,{0},{3},{2551}},
{0x0429eb10f0000334,{0},{4},{1282}},
{0x043e499372f988d5,{0},{3,1},{4028,2608}},
{0x04a9dbf56c157ea6,{0},{4},{2745}},
{0x0543ce24774a77f2,{0},{4},{1253}},
{0x054900a5c4aabacd,{0},{3},{2942}},
{0x059ad276bafb310b,{0},{4},{2942}},
{0x05e1082682de92c9,{0},{3,2,2},{2745,3517,2942}},
{0x060e39492d2c0bb1,{0},{3,2,2},{2868,2738,1699}},
{0x06548ebb7023651e,{0},{3,1},{1812,388}},
{0x06602fff59516f6d,{0},{3,2},{1739,1422}},
{0x0672c53eb50ae3e4,{0},{3,3,2,2,2,1},{2738,2868,2998,2426,2226,1978}},
{0x06943ca04a1dd63b,{0},{3},{1422}},
{0x06b3fd2c2700e4ab,{0},{3,3,2,2},{1292,1674,2434,1858}},
{0x06e8f834bdc085dd,{0},{4},{2266}},
{0x071ac9a5f924cd3f,{0},{3,2,2},{2226,2291,2356}},
{0x075f7b4b1957c637,{0},{4},{2673}},
{0x07bb701e3028e01b,{0},{3},{4028}},
{0x0959450f9df5fca5,{0},{4},{1153}},
{0x0961e2d691b3184e,{0},{3,3,3,3},{2291,2356,2942,2226}},
{0x0a323b3c3d0ea4a5,{0},{3,2,2},{2426,732,2226}},
{0x0a52491f9353477a,{0},{3,2,1},{2942,2868,2738}},
{0x0a706a55000e2905,{0},{3,2,1},{2942,2868,2998}},
{0x0a96142f7c247fdb,{0},{4},{1162}},
{0x0a988180f49c8469,{0},{4},{2803}},
{0x0ae98f287a90ee47,{0},{3,2},{3321,3063}},
{0x0b42622c90ec287f,{0},{4},{2299}},
{0x0b84dcf0f9815701,{0},{4},{2161}},
{0x0b8c498f4f6ff954,{0},{4},{4028}},
{0x0ba1308bce3c04aa,{0},{3,3,1},{1292,1350,2266}},
{0x0bbc366f060d4ed2,{0},{4},{1683}},
{0x0c98ab0b70fbcf33,{0},{4},{657}},
{0x0ce07e6f75cbfe92,{0},{3,2},{2022,1894}},
{0x0cf380140474f8c1,{0},{4},{2325}},
{0x0de5949efff23f4f,{0},{3,2,1,1},{3517,2356,2942,3321}},
{0x0de7080cb0ab475f,{0},{3},{1829}},
{0x0e42816197e9fe76,{0},{3},{1153}},
{0x0e6d4b6438ddfef2,{0},{3,3,2,2},{2356,2942,2291,2226}},
{0x0ea52a8ffa24f4d7,{0},{3,2},{1350,1153}},
{0x0fae367e050bf635,{0},{3,2},{2745,2803}},
{0x0fe6cbb6e419e698,{0},{3,3},{1739,1674}},
{0x100119752cc623e8,{0},{4},{1153}},
{0x10fb9b77273d8463,{0},{3,2},{1804,1350}},
{0x111e8b831b3397cc,{0},{3,2,2},{3322,2745,3321}},
{0x1137a3065164a9bc,{0},{3},{1153}},
{0x11652307b55967a6,{0},{3,2},{2745,2683}},
{0x119ddc1f207970ef,{0},{4},{2939}},
{0x12bab8b6f6e87f18,{0},{3},{4028}},
{0x132f931e020c3bb1,{0},{3,2,1},{1422,1350,1292}},
{0x13d2b42dbac651c3,{0},{3,1},{2942,2803}},
{0x142d4c3571f61190,{0},{4},{1810}},
{0x1437abdf5a821301,{0},{4},{1762}},
{0x144d0ece40872033,{0},{3,2,2,2},{2745,1837,2237,1661}},
{0x149f7aaf46e2394a,{0},{3},{1739}},
{0x15bb693c0a5b97d8,{0},{4},{3517}},
{0x1618f0d951f9bcd8,{0},{3,3,3},{2356,2291,2226}},
{0x17469c1a1f31071a,{0},{3,1},{1699,3063}},
{0x178412fb630a4755,{0},{3,2,1,1,1},{1422,1674,1804,2434,1153}},
{0x17868e692c533f45,{0},{3,2,2},{1350,1804,1153}},
{0x1818a9eaad3d5821,{0},{3,2,1},{2868,1699,2608}},
{0x185d859159a2b729,{0},{4},{2942}},
{0x1971aff6743ea283,{0},{3,3,2,2,2,1},{2942,2738,2226,1978,2998,2868}},
{0x198ea4b778c09d7b,{0},{4},{2942}},
{0x19a54c884605d3fa,{0},{3,3,2},{1282,705,657}},
{0x19b19d63731971b5,{0},{3,3,2,2},{1804,1739,1350,1153}},
{0x1a0df2208a6da537,{0},{4},{1764}},
{0x1a1c12e22e0ce0e0,{0},{3,2,2,2},{1837,2868,2291,2226}},
{0x1a5880ace9c57723,{0},{3},{901}},
{0x1a6cdba9800f8117,{0},{3,3,1},{3389,2237,2204}},
{0x1ade9243cce3e552,{0},{3,3,2,1},{1153,705,2332,2268}},
{0x1af4933c34104279,{0},{3,2},{1350,1804}},
{0x1ba4abe6a6a14c8d,{0},{4},{801}},
{0x1bb7821ad08a0ad7,{0},{3},{705}},
{0x1cbef16d80dc807d,{0},{3},{1422}},
{0x1ceb3151dbab99ca,{0},{3},{901}},
{0x1d01031aa629e480,{0},{3},{1749}},
{0x1d3aafcfb5131008,{0},{3,2},{2434,786}},
{0x1d5e2a3d28634416,{0},{3,2,2,2},{1669,1869,1422,1350}},
{0x1d654e073fb6f2de,{0},{3,2,1},{1674,901,1739}},
{0x1db0ba599ef8caa3,{0},{4},{2022}},
{0x1e4c615da24d277e,{0},{3,2,2,2,2},{2745,2998,2291,2942,2868}},
{0x1e50fc08b77e1895,{0},{3,2,1},{2356,2291,2803}},
{0x1e54de8fa242fc66,{0},{4},{1161}},
{0x1e770567b59891b6,{0},{3,2,2},{2942,2745,2237}},
{0x1f117e6800de0c0f,{0},{3,2},{1153,901}},
{0x1f12f1ec03a39165,{0},{3,1},{2942,3321}},
{0x1f24eb19465057ce,{0},{4},{1436}},
{0x1f3b48208bb534b3,{0},{3,2,2},{2226,3063,2291}},
{0x1fc21e0b46504c6a,{0},{3,2},{2942,1699}},
{0x20431527dd3d7b1d,{0},{3,1},{1350,1221}},
{0x20508745ad2611f6,{0},{4},{2268}},
{0x209dedc4d9604594,{0},{3,2},{2226,2291}},
{0x20b1ae8615590974,{0},{3,2,1},{388,1812,1032}},
{0x210a79e4767b1ae4,{0},{3,2},{2942,2426}},
{0x213431aa33f94c01,{0},{4},{1746}},
{0x21b08e943b4a7077,{0},{4},{1153}},
{0x21eb0ec1fc8bef59,{0},{3,2},{2333,1804}},
{0x222356beeb80cf44,{0},{3,2,2,2,1,1},{1350,1221,1674,705,1162,1153}},
{0x22491f2d0872ee17,{0},{3,2,2},{2942,2745,2803}},
{0x228fbed9f7ed46df,{0},{3,2},{774,1350}},
{0x22b1603d21639b69,{0},{3},{1350}},
{0x22e5d8f46396b3da,{0},{3,2},{2291,2356}},
{0x232501a769fb0958,{0},{3},{2942}},
{0x239656f2655c1dd7,{0},{3,3},{2942,3517}},
{0x23dce4769a963b34,{0},{4},{4028}},
{0x2490c480cb019551,{0},{3,1,1},{3517,2745,2803}},
{0x24aba0badcd42399,{0},{3,2},{3517,2745}},
{0x2558603eb28c50e6,{0},{3,1},{1032,706}},
{0x25a996a8f00da87e,{0},{4},{1749}},
{0x25aaa4532b7f99ba,{0},{3,2,1,1},{2434,1669,773,1282}},
{0x2608bf5e7c13f375,{0},{4},{2426}},
{0x26ccd466677f5b3c,{0},{3,2},{2998,2942}},
{0x27040c7c4e391b17,{0},{3,3,2},{1674,1221,705}},
{0x271eb15cdfc36a9e,{0},{3,1},{1749,2258}},
{0x275dbeb25842c019,{0},{3,3,3,2},{1978,2617,2608,2745}},
{0x27cbeff3185baa9d,{0},{3,1},{1869,786}},
{0x27d54a5b117d4258,{0},{3,2},{1350,1669}},
{0x285d6d9ca72d8bd9,{0},{4},{1357}},
{0x286dc4ef0015b162,{0},{4},{2282}},
{0x29690bc9638aefa7,{0},{3,3,2,2,2,1},{2356,2942,2226,2868,2998,2738}},
{0x29a9395c64ad3c91,{0},{3},{901}},
{0x29d4cfac69a600bd,{0},{3,3,1},{1739,1674,1422}},
{0x2a38f4db72dd13b2,{0},{4},{1749}},
{0x2a402493fe713a07,{0},{3,2,2},{1153,1739,1350}},
{0x2a67ddfcfc97b324,{0},{3,2,1},{1153,1350,1422}},
{0x2a99b6a1230aa6bf,{0},{3,2},{2203,2267}},
{0x2ae268173f095516,{0},{3,2,1},{2434,1221,1162}},
{0x2aedbccae8e9f788,{0},{4},{2942}},
{0x2afde0f6f45dd51d,{0},{3,3,1},{2291,2942,2226}},
{0x2b01a6f349d12e9d,{0},{3,2},{2942,2237}},
{0x2b5a3bde60968a32,{0},{3,2,2},{1350,1669,1869}},
{0x2b97481c98d13865,{0},{3},{3517}},
{0x2be311defb0db916,{0},{3,2},{1292,578}},
{0x2c33449b8fefd12d,{0},{3,2,2},{1487,1227,1674}},
{0x2c4e510bc6333bf4,{0},{3,2},{2291,2942}},
{0x2cf80c38c4b67da8,{0},{3,1},{4028,2738}},
{0x2cf9cab24db5888b,{0},{4},{1828}},
{0x2da145f83a165327,{0},{4},{2291}},
{0x2da4780af5792342,{0},{4},{705}},
{0x2dc49a0e99ca8ac3,{0},{3},{2745}},
{0x2de7658218171260,{0},{3,3,2},{2434,1350,2266}},
{0x2def41f2e462f3dd,{0},{4},{1153}},
{0x2e03574da7300af3,{0},{3,2,2},{1762,2608,2683}},
{0x2e14f5ce25c98112,{0},{4},{1282}},
{0x2ec66ea87999267d,{0},{3,2,2},{2942,2291,2043}},
{0x2ece4ad885ecc7c0,{0},{3,2,2,2,1},{2942,3389,2738,2226,2421}},
{0x2ed9afd3b3428e3f,{0},{3,2,1},{1569,1749,1697}},
{0x2f14467245a92866,{0},{4},{2803}},
{0x2f3d92ae10f28dae,{0},{3,2,2},{2356,2738,1978}},
{0x2f503069109065bf,{0},{3,3,3,2,2},{2356,2291,2226,2942,2745}},
{0x2f677e515bc8ee54,{0},{3},{1739}},
{0x306a653e3d6c2565,{0},{3,1},{388,771}},
{0x30b3c41aca6201d1,{0},{3,2},{2868,2226}},
{0x30b9036e251a5c34,{0},{3,3,2},{2325,1739,1153}},
{0x3159d83e8da5985f,{0},{3,2},{1739,2117}},
{0x318a320e9c0fa82a,{0},{4},{1739}},
{0x319515e87f49eee5,{0},{4},{2931}},
{0x31cc772af129dcdb,{0},{4},{2284}},
{0x31df7861905cc18d,{0},{3,2,1,1},{1661,2291,1770,2237}},
{0x3224680a530358c6,{0},{4},{388}},
{0x3317d73c4c3d1969,{0},{3,2},{901,1487}},
{0x336e48218f4fb3c7,{0},{4},{1380}},
{0x33902c34b8e18994,{0},{3,2,1,1},{2745,2942,2803,2421}},
{0x33b7da5571d6394c,{0},{3},{2226}},
{0x3401fd86681b87ef,{0},{3,2},{1097,1162}},
{0x348a1180b3522f3b,{0},{3,2,2},{2226,2942,2608}},
{0x34b842c9fb66bb0d,{0},{3,1},{2434,1350}},
{0x34e18624b58af682,{0},{4},{2608}},
{0x35837cce3862a856,{0},{3,2},{2942,1978}},
{0x35b9a0c382450144,{0},{4},{1739}},
{0x35edc8597595f03c,{0},{3,1},{2267,1282}},
{0x363356685e1e3826,{0},{3},{1999}},
{0x36af8b10dbe58b21,{0},{4},{4028}},
{0x36d6afe33dbf95a3,{0},{3,2,1},{1350,1153,2266}},
{0x371ccb5be99c125f,{0},{3,2},{2745,4028}},
{0x3846d772484da48a,{0},{3,1},{2868,2738}},
{0x385c406f07228ffa,{0},{3,2},{3517,2291}},
{0x385fd6ac718a5477,{0},{4},{617}},
{0x387bb90005c406d9,{0},{4},{2803}},
{0x3894e5cd6474877f,{0},{4},{1162}},
{0x38e04c532ad155ed,{0},{3,2},{2745,4028}},
{0x38e083e59d3e373f,{0},{4},{2291}},
{0x38eeab8e56ad437d,{0},{4},{2022}},
{0x39af58bac404a79d,{0},{4},{3321}},
{0x3a6f2c1532efb679,{0},{3,2},{1487,1739}},
{0x3b8814362f2aef53,{0},{3,1,1},{1892,2237,2291}},
{0x3c0db18f050636b8,{0},{3,2,1},{1661,1770,2237}},
{0x3d0e5319a8f49401,{0},{3,3,3,2},{2291,2673,2356,2226}},
{0x3d1cb2242a449c41,{0},{3,2},{1153,1422}},
{0x3d3ea4458be3c013,{0},{3},{1804}},
{0x3d499d94d4fade37,{0},{3},{2868}},
{0x3d4d17f4656bbc36,{0},{3,2},{2868,1978}},
{0x3d88c3a59fb2c2b6,{0},{4},{1153}},
{0x3db886ce10339f45,{0},{3},{1350}},
{0x3ec8ba4d0f752393,{0},{3,2,2,2},{1739,1804,1153,1422}},
{0x3f1105d9e0f40131,{0},{4},{1162}},
{0x3f9d25cf4a8c4928,{0},{3,2,2,1},{3063,2608,2745,3389}},
{0x3ff6a1e4c659aff3,{0},{3,2},{901,2258}},
{0x4029908054b003e5,{0},{3,2,2},{2226,2942,1978}},
{0x402ff34114a11134,{0},{3,1},{1221,2331}},
{0x4035c9ecde00e323,{0},{3,2},{3063,3322}},
{0x40989e97760684f8,{0},{3,2},{4028,1699}},
{0x40b91efebffd04fa,{0},{3,3},{1422,1739}},
{0x40c40b6ef621ee23,{0},{4},{2291}},
{0x41102a7761d92d6e,{0},{3,2,1},{1661,2291,2226}},
{0x413761a85be06fee,{0},{3,2,1,1},{1674,1422,1804,1153}},
{0x4146e2c74bbe2ae7,{0},{4},{578}},
{0x415337ff8cb71c4c,{0},{3,2},{2226,2291}},
{0x41560a0d43d86c29,{0},{3,2},{1350,1739}},
{0x420e12cedaaf98db,{0},{3,2,2},{2868,2426,2226}},
{0x42252ac8d1ce0c86,{0},{3,2,2,2},{2291,2237,1661,2745}},
{0x42a159022f042596,{0},{3,2,2},{725,1609,277}},
{0x42a38a97cc375554,{0},{3,3},{1153,1350}},
{0x4300bfdac94bd645,{0},{3,2,1},{578,1292,1422}},
{0x439217bfd6cf51cb,{0},{4},{3309}},
{0x4397ecc20890312a,{0},{3,2},{2226,2486}},
{0x43a22c7dcefe1cd3,{0},{3,2},{2426,3321}},
{0x43c5f1987971c8ed,{0},{3,2,2},{2998,2803,2868}},
{0x441956af202d76a9,{0},{4},{2745}},
{0x443556ae30a979ac,{0},{4},{2285}},
{0x44372d08e4bc7738,{0},{4},{2282}},
{0x444834712ca31395,{0},{3,3,2},{3389,1827,1661}},
{0x44864a9e2b51788f,{0},{3},{132}},
{0x451ae4e7daaa945c,{0},{3,2},{1292,1350}},
{0x4523b8ba7f938400,{0},{3,2,1},{3321,2356,2998}},
{0x45f0528a6e39b475,{0},{3},{1762}},
{0x460aaf038d93ea13,{0},{3,3,3,1},{1422,1739,1674,1097}},
{0x465a78036ebbf1e0,{0},{4},{1958}},
{0x46af9a9dbf56ff55,{0},{0},{0}},
{0x47131f3f44776347,{0},{3,3,2},{2356,2291,2942}},
{0x4781a350eaa94178,{0},{4},{2332}},
{0x47c9396f9c2e7d78,{0},{3},{1669}},
{0x484c1f3c887f6787,{0},{4},{2218}},
{0x48821db8f209b164,{0},{4},{2745}},
{0x48ff120e9aa70fc5,{0},{3},{2942}},
{0x493477ec32a4a63d,{0},{3,2},{1032,773}},
{0x4a21d3af5e0f8ad1,{0},{3,2},{2803,2226}},
{0x4a6d300354059dcc,{0},{4},{1803}},
{0x4a7d3cdfd3ea4f0d,{0},{3,1},{2868,1762}},
{0x4acdf431bfb0cc33,{0},{3},{1227}},
{0x4b576c9a76ddff67,{0},{3,2},{1357,2267}},
{0x4b9495ff30d1c76f,{0},{4},{2803}},
{0x4bd63d54075cda65,{0},{3,2},{901,1674}},
{0x4c3d6cdbdb7fa797,{0},{4},{2154}},
{0x4c5493ebfba17321,{0},{3,2,2},{3517,2745,2942}},
{0x4c6aa231a0ae7a9a,{0},{3,2,2,2},{1292,1357,705,1350}},
{0x4c76b6c3d3713d80,{0},{3,1},{2803,2738}},
{0x4ca7c8b0d4e82ef8,{0},{3,3,2},{2942,2291,2868}},
{0x4cc6fa4f929243f4,{0},{4},{2130}},
{0x4d51eb948ec43822,{0},{0},{0}},
{0x4d627ecc688240bd,{0},{3,2,1},{1978,2998,2347}},
{0x4d658ca93532348c,{0},{3},{901}},
{0x4e0fe429e72ae0f6,{0},{4},{1032}},
{0x4e1297011a588cd4,{0},{3},{1350}},
{0x4e75e9ebc89ae457,{0},{3,2},{1739,1153}},
{0x4e92e1601d31ea15,{0},{3,2,1,1},{2226,3390,2673,3323}},
{0x4e9d67e1cee562ea,{0},{3},{901}},
{0x4eda1d9cf4ca195d,{0},{4},{3322}},
{0x4ef695f3ff557a07,{0},{4},{2659}},
{0x4f2bf316a1e81ff3,{0},{3,2},{1569,2721}},
{0x4f39f3f237dc4310,{0},{3,3,2,1},{643,1292,1350,1032}},
{0x4f8ee7ea4913fb58,{0},{4},{2332}},
{0x4fa707322e9b6e01,{0},{3,3,2,2},{2868,2608,2745,2998}},
{0x4fba200c0978520a,{0},{4},{2939}},
{0x5042c9588dae8adb,{0},{3,2,1},{1739,1350,1804}},
{0x508eaba6d5e11a0a,{0},{3,2},{2237,2942}},
{0x50d55eaafe0476ac,{0},{4},{707}},
{0x514fc93b69fda04b,{0},{3},{2291}},
{0x5224a8650e95ff8b,{0},{3,2,2},{1350,1292,643}},
{0x5240587022999167,{0},{3,2,2,1},{2397,2332,773,2918}},
{0x52b72273922af62d,{0},{4},{3517}},
{0x52edef322f35a256,{0},{3},{707}},
{0x53329a46300495f8,{0},{3,2},{3389,3063}},
{0x53a784fc481acfaa,{0},{3,3,2},{2453,1227,1739}},
{0x53c361da31d2376f,{0},{4},{1161}},
{0x53d6b8ff94338993,{0},{4},{131}},
{0x53f3d4b9be44d834,{0},{3,2,2},{1350,1292,1162}},
{0x5417cc10e4f00831,{0},{4},{2325}},
{0x54ab0f9a7eecb0f4,{0},{3,2,1,1},{2266,1350,1858,2434}},
{0x55023b13a0c89960,{0},{3,2,2,1,1},{2942,3517,2226,2803,2421}},
{0x55fda1218606d9c7,{0},{3,2,2,1},{2868,2226,2738,2998}},
{0x562b14493d334cc0,{0},{3,2,2},{1739,1153,1422}},
{0x5701d0596f264805,{0},{3},{4028}},
{0x570f07da718ae252,{0},{3},{2803}},
{0x5773f3923d8d26da,{0},{3,2,1},{1350,1487,1674}},
{0x577f5bc356e4d05d,{0},{3,1},{2268,1350}},
{0x57efeddb1e4d89c5,{0},{3,2,2},{1999,2462,391}},
{0x57fc78c65b934ea2,{0},{3},{2998}},
{0x58655e17678a88e3,{0},{4},{2356}},
{0x587d5b0bde6b83bf,{0},{4},{1813}},
{0x58847addc0a10a13,{0},{3,2},{3321,3322}},
{0x58a3dddef367d608,{0},{3,2},{2426,2218}},
{0x58d30c5f09ba01de,{0},{3,2,2},{3899,2745,2738}},
{0x58e9d7f8e7dc1ed7,{0},{4},{4028}},
{0x58ea798be160b62f,{0},{4},{2738}},
{0x5908cf4cd98a7f0d,{0},{3,2},{1153,1350}},
{0x591b2f0aa0fc27fd,{0},{3},{2998}},
{0x599a8b20649e3603,{0},{4},{2874}},
{0x599d8f55bd057e2f,{0},{3,2,2,2},{2117,1669,1153,1739}},
{0x59dfc023372abd31,{0},{4},{2608}},
{0x59ef3c55b3b09eab,{0},{3},{2998}},
{0x5a21e0164471aaad,{0},{3,2},{2291,2942}},
{0x5a8bbe9e4249ea85,{0},{3,1},{1242,794}},
{0x5aec261a621fe94f,{0},{3,2,2},{2745,2868,2226}},
{0x5b547b5f88416fe4,{0},{3,2,2},{2803,2868,2745}},
{0x5b6b8822f897d460,{0},{3,2,2,1},{388,1282,2267,2331}},
{0x5ba0e46092d19f96,{0},{3,1},{2226,2608}},
{0x5c6234e26f3acd30,{0},{4},{388}},
{0x5c860b4e51433b6d,{0},{3,3,2,2,2,2},{2942,2226,1827,2745,2608,3389}},
{0x5cee4efcaaee7ae4,{0},{3},{901}},
{0x5d11683aec78e5e4,{0},{4},{388}},
{0x5d5052fab8961271,{0},{3,3,2},{1292,643,706}},
{0x5d93e9d876894905,{0},{4},{1162}},
{0x5def1b174d2ad4e8,{0},{3},{3517}},
{0x5e1a640f189434ab,{0},{4},{2868}},
{0x5e765298aedf7bc8,{0},{3},{4028}},
{0x5f103aa68e914876,{0},{3,3,2,1},{1032,1422,1153,1292}},
{0x5f517a14863dbf03,{0},{3,2},{2738,2608}},
{0x5f949af6c546ab66,{0},{3,2},{774,1227}},
{0x5faba3c3a9309fdd,{0},{3,2,2,2},{3389,2226,2745,2608}},
{0x5faf2414ccb8eecd,{0},{3,1},{2332,1221}},
{0x5fcb7cd8c7a63d1c,{0},{4},{2226}},
{0x5fda9f47a4f8e233,{0},{3,1},{3321,1764}},
{0x5fe06b3870710787,{0},{3,2,2},{2745,3321,2617}},
{0x5fe098c935f32667,{0},{3,2},{2291,2356}},
{0x6052cf7f3aecb656,{0},{3,1,1},{2285,2161,2218}},
{0x615c9571d399c528,{0},{4},{2226}},
{0x61b3bab8f6d86b03,{0},{3,2,2},{3517,2745,2942}},
{0x6202fe9d40c6c4f0,{0},{3,2,2,1},{643,1153,705,1097}},
{0x6217e3996a35b18d,{0},{4},{2868}},
{0x6267b2d1d3e9d4d1,{0},{3},{4028}},
{0x62ff8fe085b4f714,{0},{3,2,2,2,2},{2090,3690,3194,3063,3309}},
{0x63b37a5270e834de,{0},{3,2},{2285,2284}},
{0x63dd14344aa550a7,{0},{3,2},{1731,1162}},
{0x647bcfb37620117b,{0},{4},{2426}},
{0x64bf715160314e8f,{0},{4},{1661}},
{0x657914628f47a3e3,{0},{3},{1739}},
{0x65a3951f00ef018e,{0},{3,2,2},{1162,1609,1227}},
{0x65dceb347d23ff48,{0},{3,2,2},{2745,3389,2608}},
{0x6816ba4561bcf32b,{0},{4},{132}},
{0x6832ef21f1f3283d,{0},{4},{2136}},
{0x68612ea1f11fe667,{0},{4},{2942}},
{0x686b87aefb664402,{0},{3,2},{2291,2998}},
{0x68c491e972ea9c22,{0},{3,2,1},{2998,3321,1978}},
{0x695f48564153bef4,{0},{3,2,2},{1934,1221,1429}},
{0x69663c4abb087585,{0},{3,3},{3389,2608}},
{0x69d059e6c919e11f,{0},{3,3,2,2,1,1},{2998,2868,2226,2803,2356,2738}},
{0x6a1fb7c1c40ebad3,{0},{3,2,2},{2291,2738,2745}},
{0x6a44b2d95ecedba5,{0},{3,3,3},{2998,2291,2868}},
{0x6a96a8d4363420f1,{0},{0},{0}},
{0x6aafab6b7d022768,{0},{3,1,1},{388,1869,1282}},
{0x6ade8fd35604bd9c,{0},{4},{2331}},
{0x6b4801fb6ce433c7,{0},{3,2},{1032,2137}},
{0x6b8774c9fb665804,{0},{3,2},{2356,2738}},
{0x6c6d8c9e5cb598d6,{0},{3},{2745}},
{0x6c843b0772c1f37e,{0},{3,2},{1739,1669}},
{0x6ca5393794ed6887,{0},{3},{3768}},
{0x6cd048fb569977cc,{0},{3,2},{1804,1350}},
{0x6ce116789e4d51f4,{0},{3},{1347}},
{0x6cf703246ca0354c,{0},{3,2,2,1},{2673,2291,1661,2226}},
{0x6d5e37adb2841cd8,{0},{3},{1739}},
{0x6d8d57cef40a5cbd,{0},{3},{2942}},
{0x6e1b6c7f34a9eb67,{0},{3,2},{1869,1115}},
{0x6e244871f5e4f48f,{0},{3,3,2},{2745,2608,4028}},
{0x6e916b3a874c8cb7,{0},{3,2},{2745,2942}},
{0x6ea4789469f1891d,{0},{3,2},{1422,1292}},
{0x6f0053141329a920,{0},{4},{2291}},
{0x6f25c861d9764eb1,{0},{4},{2268}},
{0x6f28815958470319,{0},{3,2},{2683,3389}},
{0x6f5c6a597048138a,{0},{4},{1674}},
{0x6f886e734411b7e5,{0},{4},{2291}},
{0x6f89ecbe96ae2111,{0},{3,2,1},{1221,643,2266}},
{0x6fad145def3a26de,{0},{3,2},{2942,2803}},
{0x6fecab47873a6572,{0},{3,2},{1804,1153}},
{0x702476150f6c6501,{0},{3},{2356}},
{0x71336021369ca692,{0},{4},{1153}},
{0x716d0ab34a86f228,{0},{3,2},{2226,2868}},
{0x71d693bc81b15a13,{0},{3,2},{2918,2267}},
{0x721a4f7bab677332,{0},{3,1},{2942,2998}},
{0x72a7b3fdceb0279b,{0},{3,2},{2332,2268}},
{0x72bb2ea8db831870,{0},{3},{901}},
{0x72c9a54bbacd4347,{0},{4},{1762}},
{0x73297e1b1272872c,{0},{3,1,1},{1837,2803,1764}},
{0x73603110efd96ac1,{0},{3,2,2},{1894,2022,1999}},
{0x73cc07d5f27b0bbd,{0},{3,2},{1674,1292}},
{0x7420ed03bf3064c1,{0},{3},{2803}},
{0x7441c23ca7a9d0c5,{0},{3,2},{901,1674}},
{0x7462fd6cd8bee941,{0},{3,2,1},{2434,1350,1858}},
{0x74697eec0dd5876d,{0},{3,2},{1999,1669}},
{0x747aa606b07c660d,{0},{3,2,2,2},{1669,1422,1869,1350}},
{0x74a3e76e38b49040,{0},{4},{2738}},
{0x74af950f878ab6e6,{0},{3},{388}},
{0x74f1c97e24088e40,{0},{3,2},{1292,1162}},
{0x751cdd09053afbb4,{0},{3,2},{2942,2745}},
{0x75bbbe5efcb028d4,{0},{3,3,3,3,2},{2291,2356,2942,2226,2868}},
{0x75c2724dca390a4e,{0},{3,2,2,1},{2942,2738,3063,2933}},
{0x7629ddb6b52dda5c,{0},{4},{2291}},
{0x7635f25398c12e14,{0},{3,3},{901,1153}},
{0x76afcf59900b482d,{0},{3,2,2},{2998,2291,2226}},
{0x76b3520c853877c6,{0},{3},{2745}},
{0x76bdde6942258959,{0},{3,2},{1978,2738}},
{0x76eb5d1757c2dfee,{0},{3,2,2,2,1,1},{1153,2918,1350,1292,705,1162}},
{0x7746136d58b3a27c,{0},{3,3},{1097,131}},
{0x77498034df74f45e,{0},{3,2},{2022,2918}},
{0x774bd23645453ce1,{0},{3,2,2,1,1},{2942,2226,3389,2738,2426}},
{0x779a4c9f3cd694f3,{0},{3,2},{261,771}},
{0x781a88728b7fc1e5,{0},{4},{2426}},
{0x78e51240adb18142,{0},{3,2,2,1,1},{2942,3517,2226,2356,2803}},
{0x78f52e0da5dc921b,{0},{4},{1869}},
{0x79223816c7a6467d,{0},{4},{1634}},
{0x7944b8eb75a0906d,{0},{3,2},{1153,1350}},
{0x79f1da4f1642fc7f,{0},{4},{3517}},
{0x79f50abea747119d,{0},{3},{901}},
{0x7a10f96bb235fdb4,{0},{3,2,2,2,2},{1292,64,1227,1804,1350}},
{0x7a328a00a5c46b29,{0},{3,1},{2161,2745}},
{0x7aaa0f54479c17ee,{0},{4},{1032}},
{0x7ae6f90a625f5027,{0},{3,2},{4028,3321}},
{0x7b688066b0bd901d,{0},{4},{1350}},
{0x7bbc28bb6a35ad4a,{0},{3},{2803}},
{0x7bcc3d1a304a54e2,{0},{3,2,2,2},{1739,1350,1804,1422}},
{0x7bebc47532acddc1,{0},{3,1,1},{1422,1739,1350}},
{0x7c2907b3fdfd5072,{0},{3,2},{2608,3322}},
{0x7c6dbeaa6b2ee9d4,{0},{3,2,1},{1828,1892,2738}},
{0x7cebe482ca790ee4,{0},{3},{3259}},
{0x7d58c738381df88b,{0},{3,2,1},{1762,3517,2942}},
{0x7d6982f5d8980228,{0},{3,2},{2942,2237}},
{0x7d8cbe80fed551f9,{0},{3,2},{1350,1221}},
{0x7da5e00b80d792f9,{0},{3,2},{1739,1153}},
{0x7df445dbcff8b28e,{0},{3,2,2},{2942,2868,2226}},
{0x807950c95b11f2d7,{0},{3,1},{2942,2868}},
{0x80b2fd3aa7d527c7,{0},{4},{2291}},
{0x811fcb4d384492bb,{0},{3},{4028}},
{0x812fbb321064ade9,{0},{4},{2291}},
{0x81d2c031a59718e0,{0},{3,2,1},{1153,1350,1422}},
{0x82462b0e3240225a,{0},{3},{1674}},
{0x8282f189eb99a73d,{0},{3,2,1},{578,1292,1422}},
{0x8287131ca04a2515,{0},{3},{3517}},
{0x82fbef6b386ccd40,{0},{3,2,1},{2942,3517,2803}},
{0x830b67c0f7ca0c4b,{0},{3},{132}},
{0x8317742144be2321,{0},{3,1},{1699,2813}},
{0x83507f93c6ea2777,{0},{3},{1422}},
{0x83ef2764839fb07d,{0},{3,3,1,1},{3517,2942,1978,3321}},
{0x840643fb3d0755ac,{0},{4},{2083}},
{0x84427178bbf47b27,{0},{3},{1357}},
{0x8492327a88f10b5b,{0},{3},{2291}},
{0x85942857b0a2415c,{0},{3},{388}},
{0x85c88314cad79c6a,{0},{3,2,2},{1350,1153,1162}},
{0x85f8867aeeec30f4,{0},{3,2},{1965,1837}},
{0x86016dfe64eae589,{0},{4},{901}},
{0x8626eaafb53b05f0,{0},{3},{2434}},
{0x86aa1e8b3a487402,{0},{4},{2608}},
{0x86afd52faef9a3c6,{0},{3,2},{1804,1350}},
{0x86d311bb5924f020,{0},{3},{1350}},
{0x87463a13adc0b489,{0},{3,2,2},{2745,3517,2942}},
{0x875236692733564e,{0},{4},{2738}},
{0x8813afd40ef19bf5,{0},{4},{1837}},
{0x883f5c397e4bf9e8,{0},{3,2,2},{1674,1739,901}},
{0x8847cecda12ce20d,{0},{3,2},{2803,1177}},
{0x890c0ecd8f41b1ff,{0},{3,2,2},{2745,3321,2813}},
{0x8937833087afcb2e,{0},{3,3},{2745,1661}},
{0x89565a25a748034a,{0},{3,2},{1292,2434}},
{0x896c1e1daee86f81,{0},{4},{901}},
{0x898af5e5b55cef97,{0},{4},{1762}},
{0x8a7db35083aada3f,{0},{3,1},{4028,1770}},
{0x8a980c3507ad475c,{0},{3,2,2,2,1},{2673,2291,2745,2998,2868}},
{0x8b2d9d0aa341ea90,{0},{4},{1739}},
{0x8b52e12d2479bb8b,{0},{3,2},{1350,1804}},
{0x8b7b58e1ac6f1e5d,{0},{3,2},{1539,1350}},
{0x8babb706e99cc352,{0},{3,2},{901,1350}},
{0x8bcd48b710943ac4,{0},{3,2},{2745,2942}},
{0x8c65111a798b4917,{0},{3,2},{3390,3259}},
{0x8ca74f1438ff2ca8,{0},{3,3,3,3},{2356,2291,2942,2226}},
{0x8d1806fbdbf22dbb,{0},{3,2},{1350,901}},
{0x8db4156b062718e1,{0},{3,2,1},{1292,1153,1539}},
{0x8db96728ab1646f9,{0},{4},{1762}},
{0x8dd8346edcd5fe8d,{0},{3,2},{2291,2942}},
{0x8df58a8efdc85079,{0},{4},{1674}},
{0x8e9d3a319bdccd41,{0},{3,2,2,1},{2942,2868,2608,2226}},
{0x8eb2a3dd310da436,{0},{3},{2933}},
{0x8ef11b34412e2b2d,{0},{3,2,2},{1739,1153,1422}},
{0x8f029292a8387c15,{0},{3,2,2},{1153,1739,901}},
{0x8f15e77ee0f31786,{0},{3},{1357}},
{0x8f582fbd9f0a02b9,{0},{3,2,1,1},{2942,2868,2356,1699}},
{0x8fc91fc5d7abe465,{0},{4},{773}},
{0x8fd8dea396cdc1c0,{0},{4},{3517}},
{0x8fe333d117510e21,{0},{4},{1161}},
{0x9053f45a07b05d3c,{0},{3,2,2},{3389,2738,3321}},
{0x905a124febcf19a2,{0},{4},{2282}},
{0x905e2dbeac8ad6c0,{0},{3,3},{1544,1674}},
{0x90c072f8c3d9f19e,{0},{3,3},{1350,1422}},
{0x9120a9a86b6635f5,{0},{3},{1350}},
{0x9131fbdaf7d8bb81,{0},{4},{3063}},
{0x91324369873db97c,{0},{3,2,2,1},{2942,2356,2738,2868}},
{0x914c9905ebd2d1b8,{0},{3,2,1},{3309,1837,1763}},
{0x914ebf1e1f1b5129,{0},{3,2,2},{2738,1699,2868}},
{0x9192c3592d196960,{0},{4},{2285}},
{0x91f37b7b1537be33,{0},{3,2,1,1,1},{1674,1350,2434,1292,1858}},
{0x927647b155195ec9,{0},{3,2,1,1},{2868,2998,2942,2738}},
{0x929e6c2ba70e23d0,{0},{3,2},{2745,2803}},
{0x92ff39e5463ca982,{0},{4},{1162}},
{0x939a637bc1ba0fd1,{0},{3,2,1},{1292,1350,643}},
{0x93c58e2e4641c4de,{0},{4},{1544}},
{0x93cea4cd5cc4ad1d,{0},{3,3,3,3,1},{2998,2868,2356,2226,2738}},
{0x93e95da25e22243e,{0},{3,3,2,1},{2942,2745,2803,2998}},
{0x93fc93b08bd5a5ab,{0},{3,1},{4028,3063}},
{0x942fc5a698a3c43d,{0},{3,1,1},{1739,1674,1153}},
{0x9461c1ac46d764c7,{0},{4},{2738}},
{0x948bc9208514c584,{0},{4},{2226}},
{0x94a8ddce28a88235,{0},{3,2},{1350,1739}},
{0x94bee78bc53924a1,{0},{4},{3389}},
{0x95d8929b82a48202,{0},{3,3,1,1},{2942,1978,2426,2811}},
{0x9629e58722e993d4,{0},{4},{3387}},
{0x96b189e7337919e8,{0},{3,2},{3321,2745}},
{0x96f1bdc11f5f57a2,{0},{3,2},{1350,1292}},
{0x9740ca86275950da,{0},{3,2,1},{1153,1350,2266}},
{0x977770aa0333764c,{0},{3,1},{388,2331}},
{0x9781f294b5535795,{0},{3,2,2,1},{2942,1699,2738,2226}},
{0x979e7b60f6bba00b,{0},{4},{3063}},
{0x9801188b1bc00bf8,{0},{4},{2285}},
{0x981b8984dc02531a,{0},{3},{2659}},
{0x983e0eca99ffe76d,{0},{4},{2291}},
{0x99087c6d02d15190,{0},{4},{2934}},
{0x9909b969af6c8e6f,{0},{3},{388}},
{0x99f6c14b736a4f33,{0},{3,2,2,1},{1162,705,771,1282}},
{0x9a00fc7cdd791abb,{0},{3,1},{2745,4028}},
{0x9a18d6acc7e98acd,{0},{3,1},{1153,1674}},
{0x9a3d6430b60cca81,{0},{4},{1219}},
{0x9a79a5f22acfae2e,{0},{4},{1032}},
{0x9aab81f9cb4e9e42,{0},{3},{1153}},
{0x9acc838255e87bef,{0},{4},{2803}},
{0x9ad3577c11340430,{0},{3,2,1},{1227,1162,1739}},
{0x9b04efa2b096177a,{0},{3,2},{1837,2683}},
{0x9b1a134198411dc1,{0},{3,2},{2942,2745}},
{0x9b964f8fb186d12b,{0},{4},{2738}},
{0x9badd6e04935585e,{0},{4},{2426}},
{0x9bc79f73aac7790d,{0},{3,2,2},{1153,1350,1162}},
{0x9bd4a1a6322cce87,{0},{4},{729}},
{0x9cdb0be65ee5e817,{0},{4},{2284}},
{0x9cdf016d3c7a9e4b,{0},{3,2},{1739,2266}},
{0x9d42884793959bb1,{0},{3,2,2},{3389,2745,2813}},
{0x9d825a73278a5d88,{0},{3,2},{2813,3389}},
{0x9d912e6ced27f066,{0},{3,1},{2022,1894}},
{0x9dadc378addd4084,{0},{4},{1669}},
{0x9e043e571a9a4c56,{0},{4},{1749}},
{0x9e35b2c6d4a2d46d,{0},{3,2},{2932,2934}},
{0x9e3be0123c9fc842,{0},{4},{1350}},
{0x9e79460ae9f5ae8b,{0},{3,2},{2291,1762}},
{0x9e802625d55c617f,{0},{3,2,1},{1350,128,2266}},
{0x9e8b1f66559fc95c,{0},{4},{388}},
{0x9ead568efc85b1d2,{0},{3},{901}},
{0x9ecbba358c91ca77,{0},{4},{1033}},
{0x9f045ae44d5a23f5,{0},{3,2},{2942,3517}},
{0x9fa8c6b16d0fc9b2,{0},{4},{2486}},
{0x9fe5e082e0a3766c,{0},{3,2,2,1},{1350,1357,773,1869}},
{0x9fedde545d826ae9,{0},{4},{1683}},
{0xa03f1d3dd1ace6af,{0},{3,2},{2942,2291}},
{0xa075a2a249e36647,{0},{3,2,2},{3321,1699,2738}},
{0xa0793d47f3ada7e8,{0},{3,2},{2434,2332}},
{0xa08b62f01723c32e,{0},{3,2,1},{1292,1350,643}},
{0xa0aa5d24b523e78d,{0},{4},{1764}},
{0xa0d28604aed1c5b3,{0},{4},{2226}},
{0xa185108447fab20e,{0},{3,1},{2683,2868}},
{0xa19629b40f88cf3b,{0},{3,2,1},{1153,1292,2266}},
{0xa19757d8fa1c98da,{0},{3,3},{3389,2608}},
{0xa1ac948ead66791e,{0},{4},{2282}},
{0xa1b94c5c18e50160,{0},{4},{2426}},
{0xa25ec0f93c16ca37,{0},{4},{132}},
{0xa2bf06ee92731a9b,{0},{3,1},{2942,2868}},
{0xa31632674c57330f,{0},{3,2,1},{1739,1350,1804}},
{0xa350121d6e567248,{0},{3,3,2},{2942,1661,1827}},
{0xa375625646509d67,{0},{3,2},{1350,774}},
{0xa3ababbf66a75210,{0},{3,1,1},{2285,1978,2299}},
{0xa3afe6402b2d4c20,{0},{4},{4028}},
{0xa3d6918161409f66,{0},{4},{3517}},
{0xa46a89a8cfcbb75b,{0},{4},{3309}},
{0xa4b957065644fad5,{0},{3,2,1},{1114,1739,1347}},
{0xa4f7530c88305a2f,{0},{3,3,2,2,2,2},{2356,2226,2868,2738,2942,2803}},
{0xa4fe41b8c105b5a0,{0},{3,2},{388,643}},
{0xa50c452adaab2fe9,{0},{4},{1112}},
{0xa54f0e49626edc84,{0},{3,1},{2868,2745}},
{0xa61329239b7041c2,{0},{4},{2803}},
{0xa680ddd25919c112,{0},{4},{1764}},
{0xa69ffe36a26b9b15,{0},{3},{2998}},
{0xa6a456c50c1c95c3,{0},{3,2},{706,1153}},
{0xa6ed4d36acde7b91,{0},{3,1},{1739,1669}},
{0xa77f05bbb6d2ca59,{0},{3,2,1,1},{1350,1669,2117,1282}},
{0xa7a59ee5421597fe,{0},{3},{1282}},
{0xa7b23c66c0ec1c1f,{0},{4},{3517}},
{0xa7de7c5615cb8f8f,{0},{3,1},{2332,1153}},
{0xa7e5aadc3ac1f2e4,{0},{3,2,2},{2291,2226,1661}},
{0xa7f98539172d06ac,{0},{3,2,2,2,1},{1350,1869,1153,1669,1739}},
{0xa8b92358f3d13ea6,{0},{3},{2291}},
{0xa90824bd4238ffe1,{0},{4},{388}},
{0xa930734d169e1967,{0},{4},{2138}},
{0xa965211c31487b96,{0},{3,1},{1350,705}},
{0xa977a6281b8c39ac,{0},{3,2},{1292,1162}},
{0xa9d12fc3bfff107d,{0},{3},{2738}},
{0xaa20c80480552e8c,{0},{3},{388}},
{0xaa5c34731873c6d9,{0},{3,2,2,1},{1153,1804,1350,1422}},
{0xaa693b065029d1ae,{0},{3,2,2},{4028,2226,2291}},
{0xab28146948761c43,{0},{3},{3321}},
{0xab4ed925a1154f39,{0},{4},{2723}},
{0xac03e43b6f1ee75d,{0},{4},{1669}},
{0xac076e5bde8f855c,{0},{3},{2139}},
{0xac65cd126c710d7b,{0},{4},{2285}},
{0xac6a073e881e4521,{0},{4},{2161}},
{0xacb17485a219b78b,{0},{3,2},{1739,1227}},
{0xad33f34f90bd4ac5,{0},{3},{3517}},
{0xad45efb5bb0996de,{0},{4},{2313}},
{0xad4cd9d120982342,{0},{3,2,2},{1422,1858,2434}},
{0xad79cb9838531c36,{0},{3,1,1},{2332,774,1032}},
{0xad83c7a7cade2c06,{0},{4},{3389}},
{0xadc38e90e232b729,{0},{3,2,2},{1227,1739,1153}},
{0xadc7e01083f1f393,{0},{4},{3517}},
{0xae080e378ee6a85f,{0},{3,2,1},{3517,2942,3321}},
{0xae0a92a5c1bfd04f,{0},{3},{2291}},
{0xae4a50860cd47eeb,{0},{3,2},{1674,1487}},
{0xae74caa3793bfbb9,{0},{3},{3517}},
{0xaeab2b1e08b3fd6b,{0},{3},{4028}},
{0xaeeaa1ca7fc96289,{0},{3,2,1},{2942,2237,2745}},
{0xaf71ebf1e5674fcf,{0},{3,2},{1153,1350}},
{0xaffe69c5c43a1fb4,{0},{3,2},{2745,3389}},
{0xb07782205cecd21c,{0},{3,2,1},{2452,3028,66}},
{0xb0c209b77318aca1,{0},{4},{1350}},
{0xb0d7c5513f406bbf,{0},{3,2,2},{2803,2356,2868}},
{0xb0f94e4e7622ae95,{0},{3,2,2,1,1},{1699,2738,2226,3389,3321}},
{0xb119b6ddcc72de02,{0},{3},{901}},
{0xb1eda582df3e6754,{0},{3},{901}},
{0xb25e8f3125f46f7e,{0},{3},{901}},
{0xb2e373b740233bd7,{0},{3,1},{3517,2356}},
{0xb307ec622e081c09,{0},{4},{1097}},
{0xb31595ffefbb8309,{0},{4},{2813}},
{0xb3486388e627166b,{0},{3,2},{3069,2683}},
{0xb3670f76d825795d,{0},{3},{1153}},
{0xb3bce356beb1cd60,{0},{3,2,2},{2486,2291,2803}},
{0xb3ca4c25de38ac85,{0},{3,1},{3387,3517}},
{0xb42abc2a72f1f425,{0},{3,1},{2942,3389}},
{0xb49c19acf98d6f7c,{0},{3,2},{1177,2073}},
{0xb5a8ea2e665d3b83,{0},{3,2,2},{1544,259,454}},
{0xb5bb29506b10d4e9,{0},{4},{1810}},
{0xb5de148cd39b7ac6,{0},{3,2,1},{2738,1699,2868}},
{0xb5de85fff9ab0599,{0},{3,2,1},{3517,2942,1762}},
{0xb64affb3444c407c,{0},{3,2,2},{2868,2226,2426}},
{0xb6d8c9308eaf1451,{0},{3},{3321}},
{0xb7039370ef0a2185,{0},{3,3,1},{2908,2434,1221}},
{0xb72baad1589163cd,{0},{3,2},{2745,2803}},
{0xb774609169606d35,{0},{3,2},{2738,3389}},
{0xb78aa0c337a0c85c,{0},{3,2,2},{1097,705,1858}},
{0xb78e67e185cad0f3,{0},{3,2},{2813,3259}},
{0xb7cc013f355c696c,{0},{3},{2803}},
{0xb827f80669ffb4cc,{0},{3,2,2,2},{1153,1350,1739,1422}},
{0xb891a5356b7af290,{0},{4},{1350}},
{0xb8b7767882b2b3d3,{0},{3,2,2},{2356,2291,2942}},
{0xb90185fe21a7db89,{0},{4},{2022}},
{0xb91eb96885abe406,{0},{3,2,2},{2355,2152,1965}},
{0xb97f35b7e59c3a66,{0},{3,2},{901,1153}},
{0xba108db719dc4a90,{0},{3},{1292}},
{0xba6927705196da63,{0},{4},{1252}},
{0xbaac6794be129faa,{0},{3,2,1},{2738,2237,1371}},
{0xbb15228e08220ded,{0},{4},{1739}},
{0xbb48f726d605202b,{0},{3,2,2,2},{1153,2268,2332,705}},
{0xbb583214ad70a07d,{0},{3,3},{3389,2738}},
{0xbb5e6bb7186eb545,{0},{3,2},{1978,2426}},
{0xbb9085feb53d2219,{0},{3,2,1,1},{2933,2811,1978,2813}},
{0xbbb9a04d1dafef50,{0},{4},{578}},
{0xbbba7efc205c4362,{0},{4},{2226}},
{0xbbce06a9b7f464af,{0},{4},{1699}},
{0xbc4120a47be67405,{0},{3,2},{2237,2291}},
{0xbc440eece9da18ee,{0},{4},{3309}},
{0xbc8b1f3b1391cf15,{0},{4},{2908}},
{0xbc8f08d750df2f8f,{0},{4},{643}},
{0xbcc780fb661f2dd7,{0},{3,2,2},{1153,1739,1422}},
{0xbcff5efd38054e82,{0},{4},{578}},
{0xbe0e74f1535b3c1c,{0},{3,3},{1828,2745}},
{0xbe298d9e51bdb53f,{0},{3,3,3,1},{2226,2998,2868,2738}},
{0xbe817180932c9381,{0},{4},{2981}},
{0xbe9449fb5b915a25,{0},{3,3,2,2,1,1},{1804,1739,1350,1674,1609,1869}},
{0xbf1b66e43ddbf1fe,{0},{3,1,1},{388,1153,1739}},
{0xbf3392d3cf5a050a,{0},{3,2},{2745,2803}},
{0xbf821d66af3b5f08,{0},{3,2,1},{1739,1422,1153}},
{0xbffee111371db75d,{0},{3},{1350}},
{0xc03371e4015f4c0d,{0},{4},{3366}},
{0xc05dcd8edcfe5c44,{0},{3,2},{2942,2745}},
{0xc07f5a11b4f76b65,{0},{3,2,2},{1153,1422,1739}},
{0xc0c2a697d1203fcc,{0},{3},{3517}},
{0xc0ca38b5d7150777,{0},{3,2},{2942,2745}},
{0xc16b921e0f041658,{0},{3,3,2,2},{1739,1153,1804,1350}},
{0xc192ab886c71d770,{0},{4},{901}},
{0xc194082c29ca56ff,{0},{3,2,2,2},{1350,1292,1162,1153}},
{0xc19bad65f4712dc7,{0},{4},{2868}},
{0xc1f2ae4fea1b821e,{0},{3,2,1,1},{3387,3063,3322,3370}},
{0xc27266d865b51057,{0},{3,3,1},{2788,1869,1350}},
{0xc2bd2776b431835f,{0},{3,2,2,1},{2942,2868,2226,2426}},
{0xc2bde65d5a9a15c7,{0},{3,2,1},{3321,2813,3389}},
{0xc2fddd50b871ef41,{0},{3},{2434}},
{0xc316f2cef9285f65,{0},{3,2,2},{1892,2237,1827}},
{0xc31a5a9f9241a9e2,{0},{4},{3321}},
{0xc331d843a573d98b,{0},{3,2},{1828,3901}},
{0xc3d134f7ee355c49,{0},{4},{2285}},
{0xc3e317ef4aeed2d7,{0},{3,2},{1350,1858}},
{0xc42b6055226205e3,{0},{3,2,1,1},{2942,2226,2803,2356}},
{0xc44e6cad8a1f01a8,{0},{3},{1292}},
{0xc4e702ab7a2d9532,{0},{3,2},{1350,1153}},
{0xc5fea8ab6460c422,{0},{3,2,2,1},{1739,388,1674,1227}},
{0xc6125f88348e7b39,{0},{3,2,2},{1837,2226,2738}},
{0xc64d0168a15970b3,{0},{3,2,2},{1661,2738,3389}},
{0xc75757a6e3d12140,{0},{3,2},{2090,1770}},
{0xc77bf5db0da40d78,{0},{4},{2226}},
{0xc79a7db41188570c,{0},{4},{2942}},
{0xc7ba3b592d950a6c,{0},{4},{388}},
{0xc7f08b6d97d8929c,{0},{3,2,2,1},{2738,3321,2942,2868}},
{0xc8001cf9f1fe6521,{0},{4},{2268}},
{0xc89be8da7bd1a4b7,{0},{4},{1837}},
{0xc89ed31773b54cf0,{0},{3,2,2,1},{128,643,1221,2266}},
{0xc8bc2850ee0ea87b,{0},{3},{2346}},
{0xc8bde07f94293188,{0},{4},{2998}},
{0xc8ee88da62b6bb00,{0},{3,2},{2803,4028}},
{0xc91ddfde7592ba01,{0},{3},{707}},
{0xc95e55ff0a0ac91f,{0},{3,2},{1350,1032}},
{0xc9d66cb4c719a61d,{0},{3,3},{3389,3321}},
{0xc9f74bc4ebf9231e,{0},{4},{2096}},
{0xca1a88908234348f,{0},{4},{1739}},
{0xca1ffb950113f4f0,{0},{3,3,1},{1292,1350,2266}},
{0xcae9fbf4d1795963,{0},{3,1},{2803,2942}},
{0xcb12e529430fcdea,{0},{3,3},{901,1350}},
{0xcb18075a016c7f40,{0},{4},{1162}},
{0xcbaf214c492322f0,{0},{3,1},{2942,2421}},
{0xcbb590e5ef3d8731,{0},{4},{3836}},
{0xcbc20ace06fc10e5,{0},{3,2},{1350,1539}},
{0xccc852c8a862d9a1,{0},{3,1,1,1},{1739,2266,1292,1350}},
{0xcd0d4744acb41659,{0},{3,2,2,1},{1025,1292,1539,1422}},
{0xce291a5d9c7e9de1,{0},{3,1},{1739,2117}},
{0xcec55268e7f0abfb,{0},{3,1},{1153,1350}},
{0xcece4db10bf1a2c3,{0},{3},{1999}},
{0xced44334c59077ec,{0},{3,2,1},{3194,2618,2226}},
{0xcf3dd252278de0dc,{0},{3,1,1},{1350,1162,1153}},
{0xcf65dd49f57748f4,{0},{3,2},{3321,2426}},
{0xcfbb720d3a74b90e,{0},{3},{1661}},
{0xcfd56326eb830eef,{0},{3,3},{2608,3194}},
{0xd008110841cb718c,{0},{3,2,2,2,2},{2291,2942,2356,2868,2738}},
{0xd069ce5b4d211610,{0},{4},{2942}},
{0xd070ffa28fe1f991,{0},{4},{1350}},
{0xd0b66f5102284b0b,{0},{4},{2268}},
{0xd1734dea75661b64,{0},{3,2,2},{2683,3063,2426}},
{0xd17ba4757d4cbf62,{0},{4},{1749}},
{0xd1f7ed31b5885f91,{0},{3,3,3,2},{2868,2738,1763,1699}},
{0xd2c9543f6ce6ba79,{0},{4},{1227}},
{0xd306c73dded62d0f,{0},{4},{578}},
{0xd3213e52dc30a42c,{0},{4},{578}},
{0xd36493c3e340e1b5,{0},{3,2},{2802,2804}},
{0xd403d79056bfcba7,{0},{3},{1153}},
{0xd4ba13da86ee13c1,{0},{3,2},{1114,1242}},
{0xd4d0f3a86e840eec,{0},{4},{2325}},
{0xd4f1379ad9ca0bc0,{0},{4},{1350}},
{0xd53fa300ec14e311,{0},{3,2},{1978,1827}},
{0xd54836b86306160c,{0},{4},{1749}},
{0xd5e30cc0fe000fcc,{0},{3,2,2},{1153,1422,1739}},
{0xd5f73cc9d2444534,{0},{3,2},{705,2267}},
{0xd6ca239a63fbda6c,{0},{3,3,3},{2942,2998,2745}},
{0xd738a0bb1fc0592d,{0},{3,2},{1699,3389}},
{0xd7bfb8d3afcb1f25,{0},{4},{2291}},
{0xd8030b3c0f62f5a2,{0},{3,2},{2226,2426}},
{0xd81df6a0274ee3b8,{0},{3,2,2,1},{1221,1162,1869,1350}},
{0xd877140b3143dbc6,{0},{4},{388}},
{0xd90bd7c1c74ecf85,{0},{3,2},{1350,1674}},
{0xd9100a41b7124ffc,{0},{3,1},{2325,2396}},
{0xd9521156286fd64c,{0},{3,2},{1292,1422}},
{0xd9587b6a3ce0f14b,{0},{3},{4028}},
{0xda7b3e0cb59403ec,{0},{3},{2942}},
{0xdb0888e9dca51652,{0},{3,2,1},{3517,2226,2803}},
{0xdb5e3b51acb80e66,{0},{4},{2942}},
{0xdbdaceffcb17065b,{0},{4},{901}},
{0xdc2b7f663f476fe7,{0},{3},{2868}},
{0xdc86937c9dd264b5,{0},{4},{707}},
{0xdcfcf711b9a50821,{0},{3,2,2,1},{3389,1837,2161,2237}},
{0xdd807eedebf1fa8f,{0},{3,2,2},{1674,1162,1221}},
{0xdde93b7fde9d7593,{0},{4},{1739}},
{0xde09f33a85ec8721,{0},{4},{4028}},
{0xdea9c0c45c3a5070,{0},{3,2},{2291,3517}},
{0xdee9f4fd24ee356a,{0},{3,3,2,2,1,1},{1934,773,1869,1282,1669,1422}},
{0xdef1d4174d93aa2e,{0},{3,2,1,1},{1923,1350,1552,1999}},
{0xdf3560307faf5acc,{0},{4},{261}},
{0xdf3fb44744b2bd55,{0},{4},{3370}},
{0xdfcb9dbbac2bdf6c,{0},{4},{1177}},
{0xe0130f0b1fb0e935,{0},{4},{2942}},
{0xe02efb2e2b578f9f,{0},{3},{1609}},
{0xe03bd6ca51cf8908,{0},{4},{1739}},
{0xe0470ed6b9c09e83,{0},{3,3},{1179,2291}},
{0xe05896bcc5fab98d,{0},{4},{1869}},
{0xe0d087a25158ef9e,{0},{4},{578}},
{0xe12f7b9ba51bc183,{0},{3,2},{1097,1739}},
{0xe15d8c01ab0f96c4,{0},{3},{1153}},
{0xe1c0ebd61570cd7f,{0},{3,2,2},{2715,1292,667}},
{0xe1ef490ea23c12b5,{0},{3,2,2,2,2},{2291,2998,2356,2226,2942}},
{0xe2344918d418d9aa,{0},{3,2,1,1},{3321,3322,3389,2942}},
{0xe282f41af80e50d6,{0},{3,2},{2868,1837}},
{0xe2ddaafa6dd95b5c,{0},{3,2},{2738,3389}},
{0xe30ad626dd087ce3,{0},{4},{2942}},
{0xe312f990cc345ca8,{0},{3,2},{2299,2942}},
{0xe33a2051824b3c95,{0},{3,2,2},{2117,1739,1422}},
{0xe3bc800e9fb26547,{0},{3,2},{2942,2998}},
{0xe3ddaf31872bd143,{0},{3},{1674}},
{0xe41ad309965b0251,{0},{3,3,2},{2291,2356,2226}},
{0xe4256b42e1c3fdd5,{0},{3},{1422}},
{0xe43145e7ca60be3f,{0},{3},{3389}},
{0xe469f84c2045ddb4,{0},{4},{1764}},
{0xe475d7a90da929fc,{0},{3,3,2,1},{1739,1350,901,1153}},
{0xe47784fbe55219a8,{0},{4},{1681}},
{0xe484bf029ddb7be4,{0},{3,2},{4028,2608}},
{0xe510a0a76e711a0a,{0},{3,3},{1739,1227}},
{0xe55d7e69c0ea7ef7,{0},{3,2},{773,1032}},
{0xe57d30439bb6a089,{0},{3,3,2},{2942,1764,3321}},
{0xe58df8e31a0abdba,{0},{4},{1221}},
{0xe604ea0eecca1b48,{0},{3,3,3,3},{2356,2291,2942,2226}},
{0xe6398ffdf38acfaa,{0},{4},{2942}},
{0xe6541f19064d7529,{0},{3,2},{1153,2331}},
{0xe70c44187c382875,{0},{3},{2942}},
{0xe75106a8f5ea7aec,{0},{4},{1187}},
{0xe75cf8f39052fc5c,{0},{3,2},{2291,2942}},
{0xe7d8acd390c0fe58,{0},{3},{901}},
{0xe7f8d2c60c6aecd2,{0},{3,2},{1153,1292}},
{0xe80b3709887b8ff2,{0},{4},{1892}},
{0xe8657d8ff13f3455,{0},{3},{1091}},
{0xe8c8a4a657831685,{0},{3,2},{2161,2868}},
{0xe9e5178d5119dec1,{0},{4},{2942}},
{0xea245e4e20eacf2e,{0},{3,2},{2291,4028}},
{0xea64bd18920c4a46,{0},{3,2},{3517,2745}},
{0xeacc38d7cce20b61,{0},{3,2},{1674,1221}},
{0xeb39a22d309f6137,{0},{3,1},{1153,1292}},
{0xebfb55664ee358b5,{0},{3},{1803}},
{0xec45b2cfde1b18c9,{0},{4},{2268}},
{0xecd11548d20f1b46,{0},{4},{2874}},
{0xed5973b3447fcfbb,{0},{3,2},{3517,2942}},
{0xed987342b98e7347,{0},{3,2,2,2},{1739,1422,1350,1804}},
{0xee53f3e5d55a6c31,{0},{4},{1764}},
{0xee6e49e00ae89272,{0},{3,2,2},{2998,2868,2803}},
{0xeec149b97e0a5f4f,{0},{3},{2788}},
{0xef01296b1f711f25,{0},{3,3,1},{2683,3322,3390}},
{0xef0ff7f389e6077d,{0},{3,1},{901,1153}},
{0xef2109f095716c93,{0},{3,2,2},{3259,3309,3194}},
{0xef826d789d6052f9,{0},{3,1},{3517,2803}},
{0xefea96a0f86cc80c,{0},{4},{773}},
{0xeffa7a4bbf769e39,{0},{4},{1739}},
{0xf00d5f1dd89ded00,{0},{3,2},{1674,261}},
{0xf085e88ad8d35811,{0},{4},{1739}},
{0xf0ec25401323c157,{0},{3,2},{388,1153}},
{0xf101112a5fbd27e2,{0},{3,2,1},{1999,1350,1669}},
{0xf1333afb0f9f85d5,{0},{3,3,3},{2942,2745,2608}},
{0xf173362118b05b7c,{0},{3,2,1},{901,1674,1739}},
{0xf21a15a192645075,{0},{4},{1153}},
{0xf325b261d52993ba,{0},{3,2},{3389,1661}},
{0xf35910566040eae6,{0},{4},{1869}},
{0xf3af53f1fcba1dcb,{0},{3,1},{1739,1153}},
{0xf3b51bcdbc04f328,{0},{3},{2998}},
{0xf40327446163926d,{0},{4},{2161}},
{0xf467c65a9bc512b0,{0},{4},{4028}},
{0xf4c9413fe031d863,{0},{3,2,2},{2266,2434,643}},
{0xf500a83611d52cbb,{0},{4},{2942}},
{0xf57147f5a4a711ca,{0},{3,2},{2868,1837}},
{0xf5e3e678b9e6308b,{0},{3,2,2},{2683,3063,2426}},
{0xf60e1bdc7c255be9,{0},{3,2},{901,1350}},
{0xf629876c8c2ef91b,{0},{3},{1153}},
{0xf64ef88acec3de81,{0},{3,2,1},{901,1674,1739}},
{0xf6b16a7880a79847,{0},{4},{2739}},
{0xf6dc679941eb4e40,{0},{3},{388}},
{0xf73e4e70334b5012,{0},{3,3},{2426,3063}},
{0xf74d14622ff8ef5d,{0},{3,2},{2745,2738}},
{0xf7dc81277fe0e522,{0},{3,2},{2332,2267}},
{0xf7fb69b56a2f734d,{0},{3,1},{2942,3517}},
{0xf8042593f37917ee,{0},{3},{1350}},
{0xf8855ffb3f4ad6f5,{0},{4},{2283}},
{0xf88d2e8efc6e5060,{0},{3},{1699}},
{0xf89eaa29c36cba74,{0},{3,3,1},{1153,1350,1422}},
{0xf8b9e1f6f955f8f4,{0},{3,2,1},{2745,2942,2868}},
{0xf90ba6f96a1da475,{0},{4},{1177}},
{0xf935b8bbe9811371,{0},{4},{2226}},
{0xf94333cea3197b6c,{0},{4},{2918}},
{0xf9e4fec35bc6d385,{0},{3,2},{1422,1350}},
{0xfa06f234669168ac,{0},{3,2},{2868,2291}},
{0xfa210b5b6477e18f,{0},{3,2},{1661,2803}},
{0xfb0a411654bb80ce,{0},{3,2},{1674,2434}},
{0xfb2d0ac96e82c24e,{0},{3,2,2},{2745,2942,2998}},
{0xfb5f7d6d4088b435,{0},{4},{2745}},
{0xfb9d65807d0232af,{0},{4},{1858}},
{0xfb9f091c6a8c38f1,{0},{4},{2908}},
{0xfbb785735e976fd4,{0},{3,2,2},{2291,2942,2421}},
{0xfbd80485cd21052a,{0},{3,2},{1221,643}},
{0xfc93a0aec3e2de4d,{0},{3,2},{2426,2226}},
{0xfca2c7b7bcffbd0c,{0},{4},{2107}},
{0xfcad38e4dd26131a,{0},{3,2},{1153,1350}},
{0xfd04348e6cf9813d,{0},{3,3,2},{2291,2942,2421}},
{0xfd106e2b4ba5fe14,{0},{4},{1827}},
{0xfd321c5f264b7ae6,{0},{3,1},{1804,1350}},
{0xfd606bb92e2a9d73,{0},{3,3,2,2,1},{771,1114,1544,2203,1242}},
{0xfe2d1bd4f102549d,{0},{3,2,2},{1674,1350,2434}},
{0xff0525b5d8ae4441,{0},{4},{1828}},
{0xff41487e2aa97f77,{0},{3,2},{707,2203}},
{0xffd7bca2f8ffaead,{0},{4},{2813}},
{0xffecb374a27a60e6,{0},{4},{1382}},
}; //end of bk_default_book

//==================================================================

